@@ -75,22 +75,43 @@ def progressbar(curr, total, duration=10, extra=''):
 
 def notify_me(msg):
     '''
+    # macos desktop notification
     terminal-notifier -> https://github.com/julienXX/terminal-notifier#download
     terminal-notifier -message <msg>
-    say -v Ting-Ting <msg>
-    #Cantonese：
-    say -v Sin-ji <msg>
+
+    # ubuntu desktop notification
+    notify-send
+
+    # voice notification
+    say -v <lang> <msg>
+    lang options:
+    - Daniel:       British English
+    - Ting-Ting:    Mandarin
+    - Sin-ji:       Cantonese
     '''
+
     print(msg)
     try:
-        subprocess.run(['terminal-notifier', '-title', '🍅', '-message', msg])
-        subprocess.run(['say', '-v', 'Daniel', msg])
+        if sys.platform == 'darwin':
+            # macos desktop notification
+            subprocess.run(['terminal-notifier', '-title', '🍅', '-message', msg])
+            subprocess.run(['say', '-v', 'Daniel', msg])
+        elif sys.platform.startswith('linux'):
+            # ubuntu desktop notification
+            subprocess.Popen(["notify-send", '🍅', msg])
+        else:
+            # windows?
+            # TODO: windows notification
+            pass
+
     except:
+        # skip the notification error
         pass
 
 
 def help():
     appname = sys.argv[0]
+    appname = appname if appname.endswith('.py') else 'tomato'  # tomato is pypi package
     print('====== 🍅 Tomato Clock =======')
     print(f'{appname}         # start a {WORK_MINUTES} minutes tomato clock + {BREAK_MINUTES} minutes break')
     print(f'{appname} -t      # start a {WORK_MINUTES} minutes tomato clock')
